# There are no files that we can get debug info from
%global debug_package %{nil}

Name:		rapidjson
Version:	1.1.0
Release:	%mkrel 2
Summary:	A fast JSON parser/generator for C++
Group:		System/Libraries
License:	BSD
URL:		https://rapidjson.org/
Source0:	https://github.com/Tencent/rapidjson/archive/v%{version}/%{name}-%{version}.tar.xz
Patch1:		0001-Changed-error-code-for-invalid-special-ascii-chars-f-rediffed.patch
Patch2:		0002-Fix-905-unable-to-set-writeFlags-for-PrettyWriter-rediffed.patch
Patch3:		0003-Fixes-issue-1718-rediffed.patch
Patch10:	remove-Werror-cmakelist.patch
Patch11:	rapidjson-1.1.0-c++20.patch
Patch12:	rapidjson-1.1.0-do_not_include_gtest_src_dir.patch
Patch20:	disable-valgrind_unittest.patch
Patch21:	gcc7.patch
Patch22:	0001-Fix-Wclass-memaccess-warnings-errors.patch
Patch23:	0002-Fix-Wsign-conversion-warnings-errors.patch
Patch24:	0003-Suppress-Wformat-overflow-warning-error.patch
Patch25:	python3.patch

BuildRequires:	cmake
BuildRequires:	doxygen

%description
RapidJSON is a JSON parser and generator for C++. It was inspired by RapidXml.

- RapidJSON is small but complete. It supports both SAX and DOM style API.
  The SAX parser is only a half thousand lines of code.
- RapidJSON is fast. Its performance can be comparable to strlen(). It also
  optionally supports SSE2/SSE4.2 for acceleration.
- RapidJSON is self-contained and header-only. It does not depend on external
  libraries such as BOOST. It even does not depend on STL.
- RapidJSON is memory-friendly. Each JSON value occupies exactly 16 bytes for
  most 32/64-bit machines (excluding text string). By default it uses a fast
  memory allocator, and the parser allocates memory compactly during parsing.
- RapidJSON is Unicode-friendly. It supports UTF-8, UTF-16, UTF-32 (LE & BE),
  and their detection, validation and transcoding internally. For example, you
  can read a UTF-8 file and let RapidJSON transcode the JSON strings into
  UTF-16 in the DOM. It also supports surrogates and "\u0000" (null character)

%prep
%setup -q
%apply_patches

# Convert DOS line endings to unix
for file in "license.txt" $(find ./example -type f -name '*.c*');
do
  sed -e "s/\r$//g" < ${file} > ${file}.new && \
  touch -r ${file} ${file}.new && \
  mv -f ${file}.new ${file}
done

# Remove -march=native and -Werror from compile commands
find . -type f -name CMakeLists.txt -print0 | \
  xargs -0r sed -i -e "s/-march=native/ /g" -e "s/-Werror//g"

%build
%cmake

%make_build

%install
rm -rf %buildroot
%make_install -C build

%files
%{_includedir}/%{name}/
%{_libdir}/cmake/RapidJSON/RapidJSONConfig.cmake
%{_libdir}/cmake/RapidJSON/RapidJSONConfigVersion.cmake
%{_libdir}/pkgconfig/RapidJSON.pc
%{_datadir}/doc/RapidJSON/


%changelog
* Sat Nov 19 2022 tex - 1.1.0-2pclos2022
- apply patches from mga

* Mon Jan 27 2019 tex 1.1.0-1pclos2019
- imported package rapidjson

